==> asksuite-core-1.0.162.tgz: package/ibooking.crawler.js <==
const cheerio = require('cheerio');
const puppeteer = require('puppeteer');

async function navigateWebsite(url, checkin, checkout, adultos, criancas, bebes) {
    const browser = await puppeteer.launch({headless: true, args: ['--no-sandbox', '--disable-setuid-sandbox']});
    try {

        const mainTab = await browser.newPage();

        // Document, Stylesheet, Image, Media, Font, Script, TextTrack, XHR, Fetch, EventSource, WebSocket, Manifest, Other.
        await mainTab.setRequestInterception(true);
        mainTab.on('request', request => {
            if (request.resourceType() === 'image' || request.resourceType() === 'font' || request.resourceType() === 'stylesheet' ) {
                request.abort();
            }
            else {
                request.continue();
            }

        });

        // Navigate to a URL

        // https://lapedrerabuzios.ibookingpms.com.br/motor-de-reservas/selecionar-quarto.php?getRobotString=&getRobotsEmail=&nome=&email=&idiomaPesquisa=52&periodo1=12/12/2017&periodo2=15/12/2017&newsletter=S&quarto_1=1**undefined**0**0+&quartos=1

        await mainTab.goto(`${url}/motor-de-reservas/`);


        await mainTab.waitFor(1000);

        let strQuartos = `quarto_1=${adultos}**undefined**${criancas}**${bebes}`;

        let urlBuild = `${url}/motor-de-reservas/selecionar-quarto.php?periodo1=${checkin}&periodo2=${checkout}&cidade=&quartos=1&${strQuartos}`;

        // await mainTab.injectRemoteScript("https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js");

        console.log(urlBuild);

        await mainTab.goto(urlBuild, {timeout: 20000});


        // await mainTab.waitForPageToLoad(20000)
        await mainTab.waitForSelector('body', {timeout: 20000});


        const htmlTag = await mainTab.evaluate(function (selector) {
            const selectorHtml = document.querySelector(selector);
            return selectorHtml.innerHTML
        }, 'body'); // returns innerHTML of first matching selector for class "main"


        let $ = cheerio.load(htmlTag);
        let promise = null;

        let rooms = [];

        $("div[id^='linha_categoria']").each((index, item) => {

            let room = new HotelRoom();

            let tdx = $(item);


            let itemProce = tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(6) .swiss_721_bold');
            let exists = itemProce != null && itemProce.text().trim() != '';

            if (exists) {

                room.name = tdx.find('.DescricaoCateg').text().trim();
                room.mainPhoto = tdx.find('.imgQuarto').attr('src');
                room.description = tdx.find('section[id^="content2"] > div > div:nth-child(1)').text()
                room.amountAdults = parseInt(tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(5) span').text().trim());
                room.amountKids = 0;
                room.price = tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(4) .valorMenorCats').text().trim().replace("                                    ", "").replace("\n", "");
                room.total = tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(6) .swiss_721_bold').text().trim();


                tdx.find('.important_facility').each((index, itemAmenite) => {
                    room.amenites.push($(itemAmenite).text().trim());
                })


                tdx.find('.FotosCateg').children().each((index, itemAmenite) => {
                    room.images.push($(itemAmenite).find('img').attr('src'));
                })

                room.mainPhoto = room.images[0];


                console.log("td", room)

                rooms.push(room)
            }
        });


        if (rooms && rooms.length > 0){

            let obj = {
                data: rooms,
                url: urlBuild.replace("selecionar-quarto.php", ""),
            };

            console.log(obj.url);

            promise = Promise.resolve(obj)
        }else{
            let obj = {
                message: "Nenhum quarto foi encontrado"
            };

            promise = await Promise.reject(obj)
        }


         await browser.close();


        return promise;

    } catch (err) {
        browser.close();
        throw err;
    }
}

// //
// navigateWebsite('https://lapedrerabuzios.ibookingpms.com.br', '10/04/2018', '12/04/2018', 2, 1).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui")
//     console.log(error.message);
// })


navigateWebsite('http://pousadavalleverde.ibookingpms.com.br', '01/12/2018', '03/12/2018', 2, 0).then(data => {
    console.log("sucesso")
}).catch(error => {
    console.log("caiu aqui")
    console.log(error.message);
})

class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite}

==> asksuite-core-1.0.163.tgz: package/ibooking.crawler.js <==
const cheerio = require('cheerio');
const puppeteer = require('puppeteer');

async function navigateWebsite(url, checkin, checkout, adultos, criancas, bebes) {
    const browser = await puppeteer.launch({headless: true, args: ['--no-sandbox', '--disable-setuid-sandbox']});
    try {

        const mainTab = await browser.newPage();

        // Document, Stylesheet, Image, Media, Font, Script, TextTrack, XHR, Fetch, EventSource, WebSocket, Manifest, Other.
        await mainTab.setRequestInterception(true);
        mainTab.on('request', request => {
            if (request.resourceType() === 'image' || request.resourceType() === 'font' || request.resourceType() === 'stylesheet' ) {
                request.abort();
            }
            else {
                request.continue();
            }

        });

        // Navigate to a URL

        // https://lapedrerabuzios.ibookingpms.com.br/motor-de-reservas/selecionar-quarto.php?getRobotString=&getRobotsEmail=&nome=&email=&idiomaPesquisa=52&periodo1=12/12/2017&periodo2=15/12/2017&newsletter=S&quarto_1=1**undefined**0**0+&quartos=1

        await mainTab.goto(`${url}/motor-de-reservas/`);


        await mainTab.waitFor(1000);

        let strQuartos = `quarto_1=${adultos}**undefined**${criancas}**${bebes}`;

        let urlBuild = `${url}/motor-de-reservas/selecionar-quarto.php?periodo1=${checkin}&periodo2=${checkout}&cidade=&quartos=1&${strQuartos}`;

        // await mainTab.injectRemoteScript("https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js");

        console.log(urlBuild);

        await mainTab.goto(urlBuild, {timeout: 20000});


        // await mainTab.waitForPageToLoad(20000)
        await mainTab.waitForSelector('body', {timeout: 20000});


        const htmlTag = await mainTab.evaluate(function (selector) {
            const selectorHtml = document.querySelector(selector);
            return selectorHtml.innerHTML
        }, 'body'); // returns innerHTML of first matching selector for class "main"


        let $ = cheerio.load(htmlTag);
        let promise = null;

        let rooms = [];

        $("div[id^='linha_categoria']").each((index, item) => {

            let room = new HotelRoom();

            let tdx = $(item);


            let itemProce = tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(6) .swiss_721_bold');
            let exists = itemProce != null && itemProce.text().trim() != '';

            if (exists) {

                room.name = tdx.find('.DescricaoCateg').text().trim();
                room.mainPhoto = tdx.find('.imgQuarto').attr('src');
                room.description = tdx.find('section[id^="content2"] > div > div:nth-child(1)').text()
                room.amountAdults = parseInt(tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(5) span').text().trim());
                room.amountKids = 0;
                room.price = tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(4) .valorMenorCats').text().trim().replace("                                    ", "").replace("\n", "");
                room.total = tdx.find('section[id^="content1"]  .grupo_1  tr:nth-child(2) td:nth-child(6) .swiss_721_bold').text().trim();


                tdx.find('.important_facility').each((index, itemAmenite) => {
                    room.amenites.push($(itemAmenite).text().trim());
                })


                tdx.find('.FotosCateg').children().each((index, itemAmenite) => {
                    room.images.push($(itemAmenite).find('img').attr('src'));
                })

                room.mainPhoto = room.images[0];


                console.log("td", room)

                rooms.push(room)
            }
        });


        if (rooms && rooms.length > 0){

            let obj = {
                data: rooms,
                url: urlBuild.replace("selecionar-quarto.php", ""),
            };

            console.log(obj.url);

            promise = Promise.resolve(obj)
        }else{
            let obj = {
                message: "Nenhum quarto foi encontrado"
            };

            promise = await Promise.reject(obj)
        }


         await browser.close();


        return promise;

    } catch (err) {
        browser.close();
        throw err;
    }
}

// //
// navigateWebsite('https://lapedrerabuzios.ibookingpms.com.br', '10/04/2018', '12/04/2018', 2, 1).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui")
//     console.log(error.message);
// })

//
// navigateWebsite('http://pousadavalleverde.ibookingpms.com.br', '01/12/2018', '03/12/2018', 2, 0).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui")
//     console.log(error.message);
// })

class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite}
